read_stdin_streaming

Function read_stdin_streaming 

pub fn read_stdin_streaming<F>(process: F) -> Result<(), TokenError>
where F: FnMut(&str) -> Result<(), TokenError>,
Read stdin with a callback for each chunk (for streaming processing)

This allows processing large inputs without loading everything into memory