pub struct DetailedResult {
pub token_count: usize,
pub model_info: ModelInfo,
pub token_ids: Vec<usize>,
pub sample_tokens: Vec<String>,
}Expand description
Extended tokenization result with token details for debug mode
Reserved for future enhancement in v0.2.0 when full token ID decoding will be implemented in the debug formatter.
Fields
token_count: usizemodel_info: ModelInfotoken_ids: Vec<usize>sample_tokens: Vec<String>Trait Implementations
Sourceimpl Clone for DetailedResult
impl Clone for DetailedResult
Sourcefn clone(&self) -> DetailedResult
fn clone(&self) -> DetailedResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for DetailedResult
impl RefUnwindSafe for DetailedResult
impl Send for DetailedResult
impl Sync for DetailedResult
impl Unpin for DetailedResult
impl UnsafeUnpin for DetailedResult
impl UnwindSafe for DetailedResult