pub fn read_stdin_streaming<F>(process: F) -> Result<(), TokenError>Expand description
Read stdin with a callback for each chunk (for streaming processing)
This allows processing large inputs without loading everything into memory
pub fn read_stdin_streaming<F>(process: F) -> Result<(), TokenError>Read stdin with a callback for each chunk (for streaming processing)
This allows processing large inputs without loading everything into memory